@@ -12,9 +12,7 @@ from plotly.offline import plot as offline_plot
 __all__ = ['hydroviewer', 'forecast_stats', 'forecast_records', 'forecast_ensembles', 'historic_simulation',
            'daily_averages', 'monthly_averages', 'flow_duration_curve', 'probabilities_table', 'return_periods_table',
            'corrected_historical', 'corrected_scatterplots', 'corrected_day_average', 'corrected_month_average',
-           'corrected_volume_compare',
-           # DEPRECATED
-           'seasonal_average']
+           'corrected_volume_compare']
 
 
 # FUNCTIONS THAT PROCESS THE RESULTS OF THE API INTO A PLOTLY PLOT OR DICTIONARY
@@ -84,7 +82,7 @@ def hydroviewer(recs: pd.DataFrame, stats: pd.DataFrame, ensem: pd.DataFrame, rp
     figure.update_layout(
         title=_build_title('Forecasted Streamflow', titles),
         yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'range': [startdate, enddate]},
+        xaxis={'title': 'Date (UTC +0:00)', 'range': [startdate, enddate]},
     )
 
     if outformat == 'plotly':
@@ -98,7 +96,8 @@ def hydroviewer(recs: pd.DataFrame, stats: pd.DataFrame, ensem: pd.DataFrame, rp
         )
 
 
-def forecast_stats(stats: pd.DataFrame, rperiods: pd.DataFrame = None, titles: dict = False, outformat: str = 'plotly'):
+def forecast_stats(stats: pd.DataFrame, rperiods: pd.DataFrame = None, titles: dict = False,
+                   outformat: str = 'plotly') -> go.Figure:
     """
     Makes the streamflow data and optional metadata into a plotly plot
 
@@ -200,7 +199,8 @@ def forecast_stats(stats: pd.DataFrame, rperiods: pd.DataFrame = None, titles: d
     layout = go.Layout(
         title=_build_title('Forecasted Streamflow', titles),
         yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y', 'tickformat': '%b %d %Y'},
+        xaxis={'title': 'Date (UTC +0:00)', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y',
+               'tickformat': '%b %d %Y'},
     )
     figure = go.Figure(scatter_plots, layout=layout)
     if outformat == 'plotly':
@@ -216,7 +216,7 @@ def forecast_stats(stats: pd.DataFrame, rperiods: pd.DataFrame = None, titles: d
 
 
 def forecast_ensembles(ensem: pd.DataFrame, rperiods: pd.DataFrame = None, titles: dict = False,
-                       outformat: str = 'plotly'):
+                       outformat: str = 'plotly') -> go.Figure:
     """
     Makes the streamflow ensemble data and metadata into a plotly plot
 
@@ -284,7 +284,8 @@ def forecast_ensembles(ensem: pd.DataFrame, rperiods: pd.DataFrame = None, title
     layout = go.Layout(
         title=_build_title('Ensemble Predicted Streamflow', titles),
         yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y', 'tickformat': '%b %d %Y'},
+        xaxis={'title': 'Date (UTC +0:00)', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y',
+               'tickformat': '%b %d %Y'},
     )
     figure = go.Figure(scatter_plots, layout=layout)
     if outformat == 'plotly':
@@ -300,7 +301,7 @@ def forecast_ensembles(ensem: pd.DataFrame, rperiods: pd.DataFrame = None, title
 
 
 def forecast_records(recs: pd.DataFrame, rperiods: pd.DataFrame = None, titles: dict = False,
-                     outformat: str = 'plotly'):
+                     outformat: str = 'plotly') -> go.Figure:
     """
     Makes the streamflow saved forecast data and metadata into a plotly plot
 
@@ -348,7 +349,7 @@ def forecast_records(recs: pd.DataFrame, rperiods: pd.DataFrame = None, titles:
     layout = go.Layout(
         title=_build_title('Forecasted Streamflow Record', titles),
         yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'range': [startdate, enddate]},
+        xaxis={'title': 'Date (UTC +0:00)', 'range': [startdate, enddate]},
     )
     figure = go.Figure(scatter_plots, layout=layout)
     if outformat == 'plotly':
@@ -364,7 +365,7 @@ def forecast_records(recs: pd.DataFrame, rperiods: pd.DataFrame = None, titles:
 
 
 def historic_simulation(hist: pd.DataFrame, rperiods: pd.DataFrame = None, titles: dict = False,
-                        outformat: str = 'plotly'):
+                        outformat: str = 'plotly') -> go.Figure:
     """
     Makes the streamflow ensemble data and metadata into a plotly plot
 
@@ -412,7 +413,8 @@ def historic_simulation(hist: pd.DataFrame, rperiods: pd.DataFrame = None, title
     layout = go.Layout(
         title=_build_title('Historic Streamflow Simulation', titles),
         yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y', 'tickformat': '%Y'},
+        xaxis={'title': 'Date (UTC +0:00)', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y',
+               'tickformat': '%Y'},
     )
     figure = go.Figure(scatter_plots, layout=layout)
     if outformat == 'plotly':
@@ -427,7 +429,7 @@ def historic_simulation(hist: pd.DataFrame, rperiods: pd.DataFrame = None, title
     raise ValueError('Invalid outformat chosen. Choose json, plotly, plotly_scatters, or plotly_html')
 
 
-def daily_averages(dayavg: pd.DataFrame, titles: dict = False, outformat: str = 'plotly'):
+def daily_averages(dayavg: pd.DataFrame, titles: dict = False, outformat: str = 'plotly') -> go.Figure:
     """
     Makes the daily_averages data and metadata into a plotly plot
 
@@ -456,7 +458,7 @@ def daily_averages(dayavg: pd.DataFrame, titles: dict = False, outformat: str =
     layout = go.Layout(
         title=_build_title('Daily Average Streamflow (Simulated)', titles),
         yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'hoverformat': '%b %d', 'tickformat': '%b'},
+        xaxis={'title': 'Date (UTC +0:00)', 'hoverformat': '%b %d', 'tickformat': '%b'},
     )
     figure = go.Figure(scatter_plots, layout=layout)
     if outformat == 'plotly':
@@ -471,7 +473,7 @@ def daily_averages(dayavg: pd.DataFrame, titles: dict = False, outformat: str =
     raise ValueError('Invalid outformat chosen. Choose plotly, plotly_scatters, or plotly_html')
 
 
-def monthly_averages(monavg: pd.DataFrame, titles: dict = False, outformat: str = 'plotly'):
+def monthly_averages(monavg: pd.DataFrame, titles: dict = False, outformat: str = 'plotly') -> go.Figure:
     """
     Makes the daily_averages data and metadata into a plotly plot
 
@@ -515,7 +517,7 @@ def monthly_averages(monavg: pd.DataFrame, titles: dict = False, outformat: str
     raise ValueError('Invalid outformat chosen. Choose plotly, plotly_scatters, or plotly_html')
 
 
-def flow_duration_curve(hist: pd.DataFrame, titles: dict = False, outformat: str = 'plotly'):
+def flow_duration_curve(hist: pd.DataFrame, titles: dict = False, outformat: str = 'plotly') -> go.Figure:
     """
     Makes the streamflow ensemble data and metadata into a plotly plot
 
@@ -620,32 +622,18 @@ def probabilities_table(stats: pd.DataFrame, ensem: pd.DataFrame, rperiods: pd.D
         num50 = 0
         num100 = 0
         for column in tmp:
-            if any(i > rp100 for i in tmp[column].to_numpy()):
-                num2 += 1
-                num5 += 1
-                num10 += 1
-                num25 += 1
-                num50 += 1
+            column_max = tmp[column].to_numpy().max()
+            if column_max > rp100:
                 num100 += 1
-            elif any(i > rp50 for i in tmp[column].to_numpy()):
-                num2 += 1
-                num5 += 1
-                num10 += 1
-                num25 += 1
+            if column_max > rp50:
                 num50 += 1
-            elif any(i > rp25 for i in tmp[column].to_numpy()):
-                num2 += 1
-                num5 += 1
-                num10 += 1
+            if column_max > rp25:
                 num25 += 1
-            elif any(i > rp10 for i in tmp[column].to_numpy()):
-                num2 += 1
-                num5 += 1
+            if column_max > rp10:
                 num10 += 1
-            elif any(i > rp5 for i in tmp[column].to_numpy()):
-                num2 += 1
+            if column_max > rp5:
                 num5 += 1
-            elif any(i > rp2 for i in tmp[column].to_numpy()):
+            if column_max > rp2:
                 num2 += 1
         r2.append(round(num2 * 100 / 52))
         r5.append(round(num5 * 100 / 52))
@@ -755,7 +743,8 @@ def corrected_historical(corrected: pd.DataFrame, simulated: pd.DataFrame, obser
     layout = go.Layout(
         title=_build_title("Historical Simulation Comparison", titles),
         yaxis={'title': 'Discharge (m<sup>3</sup>/s)'},
-        xaxis={'title': 'Date', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y', 'tickformat': '%Y'},
+        xaxis={'title': 'Date (UTC +0:00)', 'range': [startdate, enddate], 'hoverformat': '%b %d %Y',
+               'tickformat': '%Y'},
     )
 
     figure = go.Figure(data=scatters, layout=layout)
@@ -1135,70 +1124,3 @@ def _rperiod_scatters(startdate: str, enddate: str, rperiods: pd.DataFrame, y_ma
             template(f'50 Year: {r50}', (r50, r50, r100, r100), colors['50 Year']),
             template(f'100 Year: {r100}', (r100, r100, rmax, rmax), colors['100 Year']),
         ]
-
-
-# DEPRECATED
-def seasonal_average(seas: pd.DataFrame, titles: dict = False, outformat: str = 'plotly'):
-    """
-    Makes the streamflow ensemble data and metadata into a plotly plot
-
-    Args:
-        seas: the csv response from seasonal_average
-        titles: (dict) Extra info to show on the title of the plot. For example:
-            {'Reach ID': 1234567, 'Drainage Area': '1000km^2'}
-        outformat: either 'json', 'plotly', or 'plotly_html' (default plotly)
-
-    Return:
-         plotly.GraphObject: plotly object, especially for use with python notebooks and the .show() method
-    """
-    if outformat not in ['json', 'plotly_scatters', 'plotly', 'plotly_html']:
-        raise ValueError('invalid outformat specified. pick json, plotly, plotly_scatters, or plotly_html')
-
-    plot_data = {
-        'day_number': seas.index.tolist(),
-        'average_flow': seas['streamflow_m^3/s'].tolist(),
-        'max_flow': seas['max_flow'].tolist(),
-        'min_flow': seas['min_flow'].tolist(),
-    }
-    if outformat == 'json':
-        return plot_data
-
-    scatter_plots = [
-        go.Scatter(
-            name='Average Daily Flow',
-            x=plot_data['day_number'],
-            y=plot_data['average_flow'],
-            line=dict(color='blue')
-        ),
-        go.Scatter(
-            name='Maximum Daily Flow',
-            x=plot_data['day_number'],
-            y=plot_data['max_flow'],
-            line=dict(color='red')
-        ),
-        go.Scatter(
-            name='Minimum Daily Flow',
-            x=plot_data['day_number'],
-            y=plot_data['min_flow'],
-            line=dict(color='black')
-        ),
-    ]
-    if outformat == 'plotly_scatters':
-        return scatter_plots
-    layout = go.Layout(
-        title=_build_title('Daily Average Streamflow (Historic Simulation)', titles),
-        yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
-        xaxis={'title': 'Date', 'range': [plot_data['day_number'][0], plot_data['day_number'][-1]],
-               'hoverformat': '%b %d (%j)', 'tickformat': '%b'},
-    )
-    figure = go.Figure(scatter_plots, layout=layout)
-    if outformat == 'plotly':
-        return figure
-    if outformat == 'plotly_html':
-        return offline_plot(
-            figure,
-            config={'autosizable': True, 'responsive': True},
-            output_type='div',
-            include_plotlyjs=False
-        )
-    raise ValueError('Invalid outformat chosen. Choose json, plotly, plotly_scatters, or plotly_html')
